"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports["default"] = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _engine = require("@aomao/engine");

var _uuid = require("uuid");

var _pluginImage = require("@aomao/plugin-image");

// @ts-nocheck
// import { ImageValue } from 'plugins/image/dist/component';
// 继承原 ImageUploader 类，重写 execute 方法
var CustomizeImageUploader = /*#__PURE__*/function (_ImageUploader) {
  (0, _inheritsLoose2["default"])(CustomizeImageUploader, _ImageUploader);

  function CustomizeImageUploader() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _ImageUploader.call.apply(_ImageUploader, [this].concat(args)) || this;
    _this.imageComponents = {};
    return _this;
  }

  var _proto = CustomizeImageUploader.prototype;

  // 上传前处理图片，获取图片的base64在上传等待中显示在编辑器中
  _proto.handleBefore = function handleBefore(uid, file) {
    var _this2 = this;

    var type = file.type,
        name = file.name,
        size = file.size; // 获取文件后缀名

    var ext = (0, _engine.getExtensionName)(file); // 异步读取文件

    return new Promise(function (resolve, reject) {
      var fileReader = new FileReader();
      fileReader.addEventListener('load', function () {
        var values = {
          file: file,
          info: {
            // 唯一编号
            uid: uid,
            // Blob
            src: fileReader.result,
            // 文件名称
            name: name,
            // 文件大小
            size: size,
            // 文件类型
            type: type,
            // 文件后缀名
            ext: ext
          }
        }; // 如果是图片，则获取图片的宽高

        var base64 = values.info.src;
        var image = new Image();
        image.src = values.info.src; // eslint-disable-next-line no-tabs

        var imagePlugin = _this2.editor.plugin.findPlugin('image');

        image.onload = function () {
          var _imagePlugin$options;

          var naturalWidth = image.naturalWidth,
              naturalHeight = image.naturalHeight,
              height = image.height,
              width = image.width;
          var w_h_pre = width / height;
          var w_h_pre_num = 150;
          var imageWidth = w_h_pre > 1 ? w_h_pre_num : w_h_pre_num * w_h_pre;
          var imageHeight = w_h_pre > 1 ? w_h_pre_num / w_h_pre : w_h_pre_num;
          var maxHeight = imagePlugin === null || imagePlugin === void 0 ? void 0 : (_imagePlugin$options = imagePlugin.options) === null || _imagePlugin$options === void 0 ? void 0 : _imagePlugin$options.maxHeight;

          if (maxHeight && naturalHeight > naturalWidth && height > maxHeight) {
            imageHeight = maxHeight;
            imageWidth = naturalWidth * (maxHeight / naturalHeight);
          }

          values.base64 = base64;
          values.size = {
            width: imageWidth,
            height: imageHeight,
            naturalHeight: image.naturalHeight,
            naturalWidth: image.naturalWidth
          };
          resolve(values);
        };

        image.onerror = function () {
          reject(false);
        };
      }, false);
      fileReader.addEventListener('error', function () {
        reject(false);
      });
      fileReader.readAsDataURL(file);
    });
  } // 上传前插入编辑器
  ;

  _proto.onReady = function onReady(fileInfo, base64, size) {
    // 如果当前图片的 ImageComponent 实例存在就不处理
    if (!(0, _engine.isEngine)(this.editor) || !!this.imageComponents[fileInfo.uid]) {
      return;
    } // 插入ImageComponent 卡片


    var component = this.editor.card.insert(_pluginImage.ImageComponent.cardName, {
      // 设置状态为上传中
      status: 'uploading',
      size: size
    }, // 显示在 handleBefore 中获取的 base64 图片，这样不会导致编辑器区域空白
    base64); // 记录当前上传文件的 卡片实例

    this.imageComponents[fileInfo.uid] = component;
  } // // 上传中
  // onUploading(uid: string, { percent }: { percent: number }) {
  //   // 获取file 对应的 ImageComponent 实例
  //   const component = this.imageComponents[uid];
  //   if (!component) return;
  //   // 设置当前上传进度百分比
  //   // component.setProgressPercent(percent);
  // }
  // 上传成功
  ;

  _proto.onSuccess = function onSuccess(response, uid) {
    // 获取file 对应的 ImageComponent 实例
    var component = this.imageComponents[uid];
    if (!component) return; // 获取上传成功后的图片地址

    var src = ''; // 处理服务端返回的 response，如果上传出错就更新对应 file 对应的 ImageComponent 实例的状态值

    if (!response.result) {
      // 更新卡片的值
      this.editor.card.update(component.id, {
        status: 'error',
        message: response.message || this.editor.language.get('image', 'uploadError')
      });
    } else {
      // 上传成功
      src = response.data;
    } // 设置为file 对应的 ImageComponent 实例的状态值为 done


    var value = {
      status: 'done',
      src: src
    }; // 有获取的上传图片后的url

    if (src) {
      // 调用 ImageUploader 当前实例的方法去加载这个 url 图片，如果加载失败，就设置状态为error并显示无法加载，否则就正常加载图片
      this.loadImage(component.id, value);
    } // 删除当前的临时记录


    delete this.imageComponents[uid];
  } // 上传出错
  // eslint-disable-next-line @typescript-eslint/explicit-function-return-type
  ;

  _proto.onError = function onError(error, uid) {
    var component = this.imageComponents[uid];
    if (!component) return; // 更新卡片状态为 error，并显示错误信息

    this.editor.card.update(component.id, {
      status: 'error',
      message: error.message || this.editor.language.get('image', 'uploadError')
    }); // 删除当前的临时记录

    delete this.imageComponents[uid];
  } // eslint-disable-next-line @typescript-eslint/explicit-function-return-type
  ;

  _proto.execute =
  /*#__PURE__*/
  function () {
    var _execute = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee(files) {
      var _this3 = this;

      var _this$editor, request, language, limitSize, promiseList, f, file, uid;

      return _regenerator["default"].wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              if ((0, _engine.isEngine)(this.editor)) {
                _context.next = 2;
                break;
              }

              return _context.abrupt("return");

            case 2:
              // 获取当前传入的可选项值
              _this$editor = this.editor, request = _this$editor.request, language = _this$editor.language; // 上传大小限制

              limitSize = this.options.file.limitSize || 5 * 1024 * 1024; // 传入的files不是数组获取不是图片地址，那就是 MouseEvent 弹出文件选择器

              if (!(!Array.isArray(files) && typeof files !== 'string')) {
                _context.next = 10;
                break;
              }

              _context.next = 7;
              return request.getFiles({
                // 用户目标的单击事件
                event: files,
                // 可选取的文件后缀名称。this.extensionNames 是 ImageUploader 插件内默认支持的后缀和可选项传进来的后缀合并后的值
                // eslint-disable-next-line no-nested-ternary
                accept: _engine.isAndroid ? 'image/*' : this.extensionNames.length > 0 ? "." + this.extensionNames.join(',.') : '',
                // 最多可选取数量
                multiple: 1
              });

            case 7:
              files = _context.sent;
              _context.next = 13;
              break;

            case 10:
              if (!(typeof files === 'string')) {
                _context.next = 13;
                break;
              }

              this.insertRemote(files);
              return _context.abrupt("return");

            case 13:
              if (!(files.length === 0)) {
                _context.next = 15;
                break;
              }

              return _context.abrupt("return");

            case 15:
              promiseList = []; // eslint-disable-next-line no-plusplus

              f = 0;

            case 17:
              if (!(f < files.length)) {
                _context.next = 27;
                break;
              }

              file = files[f]; // 当前上传文件唯一标识

              uid = Date.now() + "-" + f; // 判断文件大小

              if (!(file.size > limitSize)) {
                _context.next = 23;
                break;
              }

              // 显示错误
              this.editor.messageError(language.get('image', 'uploadLimitError').replace('$size', (limitSize / 1024 / 1024).toFixed(0) + "M"));
              return _context.abrupt("return");

            case 23:
              promiseList.push(this.handleBefore(uid, file));

            case 24:
              f++;
              _context.next = 17;
              break;

            case 27:
              // 全部图片读取完成后再插入编辑器
              Promise.all(promiseList).then(function (values) {
                if (values.some(function (value) {
                  return value === false;
                })) {
                  _this3.editor.messageError('read image failed');

                  return;
                }

                var files = values;
                files.forEach(function (v) {
                  // 插入编辑器
                  _this3.onReady(v.info, v.base64, v.size);
                }); // 处理上传

                _this3.handleUpload(files);
              });

            case 28:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function execute(_x) {
      return _execute.apply(this, arguments);
    }

    return execute;
  }()
  /**
   * 处理文件上传
   * @param values
  */
  ;

  _proto.handleUpload = function handleUpload(values) {
    var _this4 = this;

    var files = values.map(function (v) {
      v.file.uid = v.info.uid;
      return v.file;
    });
    var imageType = files[0].type.split('/')[1];
    /* 创建 XMLHttpRequest 对象 */
    // 将file文件设置成form数据
    // 读取前置文件

    var yEditorOssConfigs = JSON.parse(localStorage.getItem('yEditorOssConfigs') || '{}'); // eslint-disable-next-line @iceworks/best-practices/recommend-polyfill

    fetch( // eslint-disable-next-line max-len
    "https://" + yEditorOssConfigs.domain + "/oss/getSignatureInfo?projectId=" + yEditorOssConfigs.projectId + "&dir=" + yEditorOssConfigs.dir + "&securityType=public", {
      method: 'GET'
    }).then(function (res) {
      // 处理http响应
      res.json().then(function (resData) {
        var result = resData && resData.data;

        if (result && result.signature) {
          var fileForm = new FormData();
          fileForm.append('key', "" + (result === null || result === void 0 ? void 0 : result.dir) + (0, _uuid.v4)() + "." + imageType);
          fileForm.append('policy', result.policy || '');
          fileForm.append('OSSAccessKeyId', (result === null || result === void 0 ? void 0 : result.accessId) || '');
          fileForm.append('success_action_status', '201');
          fileForm.append('signature', (result === null || result === void 0 ? void 0 : result.signature) || '');
          fileForm.append('file', files[0]);
          var httpRequest = new XMLHttpRequest();
          httpRequest.open('POST', result.host || ''); // httpRequest.setRequestHeader('Content-type', 'multipart/form-data');

          httpRequest.setRequestHeader('X-TOKEN', yEditorOssConfigs.tokenKey ? localStorage.getItem(yEditorOssConfigs.tokenKey) : '');
          httpRequest.send(fileForm); // 发送请求 将json写入send中

          httpRequest.onreadystatechange = function () {
            if (httpRequest.readyState === 4) {
              if (httpRequest.status === 200 || httpRequest.status === 201) {
                var json = httpRequest.responseText; // 获取到服务端返回的数据

                _this4.onSuccess({
                  result: true,
                  data: json.split('<Location>')[1].split('</Location>')[0]
                }, values[0].info.uid);
              } else {
                _this4.onError({
                  message: '上传失败，请检查文件！'
                }, values[0].info.uid);
              }
            }
          };

          return result;
        } else {
          // 处理错误
          _this4.onError(error, values[0].info.uid || '');
        }
      })["catch"](function () {
        // 处理错误
        _this4.onError({
          message: '上传失败，请检查配置及文件！'
        }, values[0].info.uid || '');
      });
    }, function () {
      // 处理错误
      _this4.onError({
        message: '上传失败，请检查配置及文件！'
      }, values[0].info.uid || '');
    }); // this.editor.request.upload(
    //   {
    //     url: this.options.file.action,
    //     data: {
    //       ...this.options.file.data,
    //       file: files[0],
    //     },
    //     onSuccess: (response, file) => {
    //       this.onSuccess(response, file.uid || '');
    //     },
    //     onError: (error, file) => {
    //       this.onError(error, file.uid || '');
    //     },
    //   },
    //   files,
    // );
  };

  return CustomizeImageUploader;
}(_pluginImage.ImageUploader);

var _default = CustomizeImageUploader;
exports["default"] = _default;